#Solution of the first-order reliability method (FORM) using Low and Tang (2007) 's algorithm

	# author Xingzheng Wu email xingzhengwu@gmail.com
	#references
	#[1] Wu XZ. 2015. Implementing multivariate fitting and reliability analyses for geotechnical engineering problems in R. Journal of Earth System Science. 
	#[2] Low B K and Tang W H 2007 Efficient spreadsheet algorithm for first-order reliability method; J. Eng. Mech. 133(12) 1378-1387.
	#[3] Phoon K K and Honjo Y 2005 Geotechnical reliability analyses: towards development of some user-friendly tools; In Proceedings of the 16th International Conference on Soil Mechanics and Geotechnical engineering. Osaka. 
	#[4]Wu X.Z. 2013. Probabilistic slope stability analysis by a copula-based sampling method. Computational Geosciences. 2013. 17(5):739-755.
	#2015/5/22
	
	# Appendix A3.2 of Wu (2015)
	##	install.packages("Rdonlp2")  #Rdonlp2_0.3-1.zip
	library(Rdonlp2)
	nVars<-2; ncols<-nVars; nrows<-nVars

	FunXiLT<-function(DistName,para1,para2,ni){if (DistName=="norm") {
		xi_LT=para1+ni*para2}; list(xi_LT=xi_LT)
		}

	ObjFn<-function(par){
		x1<-par[1]; x2<-par[2];
		ncols<-2; nrows<-2
		X12.Corr<-0.66; X21.Corr<-0.66
		corrm4<-matrix(c(1,X12.Corr,X21.Corr,1.0),ncol=ncols,nrow=nrows,byrow=TRUE)
		CormInv<-solve(corrm4)
		matXMinusM<-t(t(c(x1,x2)))
		sqrt(t(matXMinusM) %*% CormInv %*% matXMinusM)
		}
	par.l<-c(-500,-500); par.u<-c(50,60)
	nlinbd<-matrix(0,nr=1,nc=2)

	gFn<-function(par){
		x1<-par[1];x2<-par[2];
		X1_mu=18.00; X1_sd=1.8; X2_mu=40.00/180*pi; X2_sd=8/180*pi;
		z1<-FunXiLT("norm",X1_mu,X1_sd,x1)$xi_LT
		z2<-FunXiLT("norm",X2_mu,X2_sd,x2)$xi_LT
		BW<-1; DD<-10; ed<-1; FL<-1000
		z1*BW*DD^3/(2*(ed+DD))*tan(pi/4+z2/2)^2-FL
		}
	nlinbd[1,]<-c(-Inf,0)
	p0<-c(0.0,0.0) #n1,n2
	cntl<-donlp2.control(del0=0.2,tau0=1.0,tau=0.1,taubnd=5e-6)
	res<-donlp2(par=p0,fn=ObjFn,par.u=par.u,par.l=par.l,nlin=list(gFn),nlin.upper=nlinbd[,2],
	nlin.lower=nlinbd[,1],control=cntl)
	beta1<-res$f
	beta1
